package cn.com.qmth.examcloud.core.oe.task.starter.config;

import cn.com.qmth.examcloud.core.oe.task.service.job.*;
import com.xxl.job.core.context.XxlJobHelper;
import com.xxl.job.core.handler.annotation.XxlJob;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

/**
 * 网考任务执行器
 */
@Component
public class OeTaskExecutor {

    private static final Logger log = LoggerFactory.getLogger(OeTaskExecutor.class);

    @Autowired
    private BeforeHandInExamJobHandler beforeHandInExamJobHandler;

    @Autowired
    private AfterHandInExamJobHandler afterHandInExamJobHandler;

    @Autowired
    private SyncExamRecordDataJobHandler syncExamRecordDataJobHandler;

    @Autowired
    private FaceVerifyJobHandler faceVerifyJobHandler;

    @Autowired
    private ClearExpireDataJobHandler clearExpireDataJobHandler;

    /**
     * 1、处理交卷前考试数据任务
     */
    @XxlJob("beforeHandInExamJobHandler")
    public void beforeHandInExamJobHandler() throws Exception {
        int shardIndex = XxlJobHelper.getShardIndex();
        int shardTotal = XxlJobHelper.getShardTotal();
        String jobParam = XxlJobHelper.getJobParam();
        XxlJobHelper.log("shardTotal:{}, shardIndex:{}", shardTotal, shardIndex);
        beforeHandInExamJobHandler.run(shardTotal, shardIndex, jobParam);
    }

    /**
     * 2、处理交卷后考试数据任务
     */
    @XxlJob("afterHandInExamJobHandler")
    public void afterHandInExamJobHandler() throws Exception {
        int shardIndex = XxlJobHelper.getShardIndex();
        int shardTotal = XxlJobHelper.getShardTotal();
        String jobParam = XxlJobHelper.getJobParam();
        XxlJobHelper.log("shardTotal:{}, shardIndex:{}", shardTotal, shardIndex);
        afterHandInExamJobHandler.run(shardTotal, shardIndex, jobParam);
    }

    /**
     * 3、同步考试记录数据任务
     */
    @XxlJob("syncExamRecordDataJobHandler")
    public void syncExamRecordDataJobHandler() throws Exception {
        int shardIndex = XxlJobHelper.getShardIndex();
        int shardTotal = XxlJobHelper.getShardTotal();
        String jobParam = XxlJobHelper.getJobParam();
        XxlJobHelper.log("shardTotal:{}, shardIndex:{}", shardTotal, shardIndex);
        syncExamRecordDataJobHandler.run(shardTotal, shardIndex, jobParam);
    }

    /**
     * 处理考试过程中抓拍照片比对任务
     */
    @XxlJob("faceVerifyJobHandler")
    public void faceVerifyJobHandler() throws Exception {
        int shardIndex = XxlJobHelper.getShardIndex();
        int shardTotal = XxlJobHelper.getShardTotal();
        String jobParam = XxlJobHelper.getJobParam();
        XxlJobHelper.log("shardTotal:{}, shardIndex:{}, jobParam:{}", shardTotal, shardIndex, jobParam);
        faceVerifyJobHandler.run(shardTotal, shardIndex, jobParam);
    }

    /**
     * 清理过期数据任务
     */
    @XxlJob("clearExpireDataJobHandler")
    public void clearExpireDataJobHandler() throws Exception {
        int shardIndex = XxlJobHelper.getShardIndex();
        int shardTotal = XxlJobHelper.getShardTotal();
        String jobParam = XxlJobHelper.getJobParam();
        XxlJobHelper.log("shardTotal:{}, shardIndex:{}, jobParam:{}", shardTotal, shardIndex, jobParam);
        clearExpireDataJobHandler.run(shardTotal, shardIndex, jobParam);
    }

}
